// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: ProductAtts
// Author: Richard Saxton
//
// Description: Concrete implementation of ArfDataServer class
//
// Comments:
//
// Modifications: See ChangeLog
//
// $Id: ProductAtts.h,v 1.4 2012/03/23 09:25:00 rsaxton Exp $

#ifndef ProductAtts_H
#define ProductAtts_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include "CalServer.h"
#include "Dal.h"
#include "Tracer.h"
#include "DataSubspace.h"

/* Local Classes */

/****************************************************
 *
 * class ProductAtts
 *
 ***************************************************/

class ProductAtts
{
public:

  //ProductAtts(const string & datafile);
  ProductAtts(const string & datafile);

  ~ProductAtts();

  /********************************************
   *
   * General observation/mission/instrument info
   *
   ********************************************/

  Xmm::Instrument instrumentID()   const;


  const string               datafile()            const;
  const string               instrument()          const;
  const string               telescope()           const;
  const string               datamode()            const;
  const string               observationDate()     const;
  const string               observationDateEnd()  const;
  const string               observingMode()       const;
  const string               filter  ()            const;
  const string               ppsvers ()            const;
  const string               coordtype ()            const;
  /* AI gcc4 porting
   *   error: type qualifiers ignored on function return type
   *   => const int.. removed
   */
   int                  emdhlow ()            const;
   int                  emdhupp ()            const;
   int                  ccdNr ()              const;
   int                  spec_SRCPOS()         const;
/* AI gcc4 porting
 * end
 */
  /**************************
   *
   * Pointing info
   *
   **************************/

  /* Mean s/c pointing */
  double                     rapnt()                   const ;
  double                     decpnt()                  const ;
  double                     papnt()                   const ;

  /**************************
   *
   * Timing info
   *
   **************************/

  double                     frameTime()               const ;

  /********************************************
   *
   * Selection info
   *
   ********************************************/

  const string              expression()   const;
  const string              productType()   const;
  double 		    dlmean() const;
  double 		    exptime() const;
  double 		    backscale() const;

  int			    binsize() const;
  int			    specmin() const;
  int			    specmax() const;
  int			    xbins() const;
  int			    ybins() const;
  int			    ximagemin() const;
  int			    ximagemax() const;
  int			    yimagemin() const;
  int			    yimagemax() const;
  
  string 		    xcolumn() const;
  string 		    ycolumn() const;

private:

  // Get product-specific attributes
  void getSpectrumAttributes();
  void getImageAttributes();
  void      readWindowMode();

  string               _datafile;
  string               _productType;

  DataSet              * _set;

  Xmm::Instrument       _instrumentID;
  string               _instrument;
  string               _telescope;
  string               _filter;
  string               _datamode;
  string               _submode;
  string               _dateobs;
  string               _dateend;
  string               _ppsvers;
  string               _coordtype;
  string               _expression;
  string	       _xcolumn;
  string	       _ycolumn;

  double               _rapnt;
  double               _decpnt;
  double               _papnt;
  double               _frameTime;
  double               _dlmean;
  double               _exptime;
  double               _backscale;
  int		       _binsize;

  int                  _emdhlow;
  int                  _emdhupp;
  int                  _specmin, _specmax;
  int 		       _xbins, _ybins;
  int                  _ximagemin, _yimagemin;
  int                  _ximagemax, _yimagemax;

  Xmm::Mode           _windowMode;
};

#endif
