// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: QPBselect
// Author: Richard Saxton
//
// Description: Produces a spectrum or image from quiescent
// particle background (QPB) events
//
// Comments:
//
// Modifications: See ChangeLog
//
// $Id: QPBselect.h,v 1.4 2012/03/23 09:25:00 rsaxton Exp $

#ifndef QPBselect_H
#define QPBselect_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include "CalServer.h"
#include "Dal.h"
#include "Tracer.h"
#include "DataSubspace.h"
#include "ProductAtts.h"

/* Local Classes */

/****************************************************
 *
 * class QPBselect
 *
 ***************************************************/

class QPBselect
{
public:

  //QPBselect(const string & datafile);
  QPBselect();

  ~QPBselect();

  /********************************************
   *
   * Methods
   *
   ********************************************/

  // Make a temporary QPB event file
  void  makeQPBeventfile(string & input_event_file, 
                           string & tempeventfile, 
			   bool useodfatt,
                           string & attfile, 
                           bool overwritesubmode, double scale_factor);

  // Make the final output product
  DataSet * makeProduct(string & tempeventfile, string & outprod, 
                                ProductAtts *dfatt);

  // Sets any extra attributes which are needed
  void updateAttributes( DataSet * inset, ProductAtts *dfatt,
                         double scale_factor);

  void scaleRates(DataSet *outset, ProductAtts *dfatt, double scale_factor);

};

#endif
